@@ -348,7 +348,7 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         ip, port = connection_properties['target_portal'].rsplit(':', 1)
         # NOTE(geguileo): I don't know if IPv6 will be reported with []
         # or not, so we'll make them optional.
-        ip = ip.replace('[', '\[?').replace(']', '\]?')
+        ip = ip.replace('[', r'\[?').replace(']', r'\]?')
         out = self._run_iscsiadm_bare(['-m', 'discoverydb',
                                        '-o', 'show',
                                        '-P', 1])[0] or ""
@@ -517,7 +517,6 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
             with excutils.save_and_reraise_exception():
                 self._cleanup_connection(connection_properties, force=True)
 
-    @utils.retry(exceptions=(exception.VolumeDeviceNotFound))
     def _get_device_link(self, wwn, device, mpath):
         # These are the default symlinks that should always be there
         if mpath:
